==> haskell-persistent-postgresql-2.13.4.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-postgresql
version:              2.13.4.1
visibility:           public
id:                   persistent-postgresql-2.13.4.1-AN5PZR7PkYTIADU5ExKLfE
key:                  persistent-postgresql-2.13.4.1-AN5PZR7PkYTIADU5ExKLfE
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  5237de4b24f66e0af14b3d1df9f17ee2
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.4.1-AN5PZR7PkYTIADU5ExKLfE
depends:
    aeson-2.1.2.1-GLiPeiAR7ZSFwx9H49aVEA
    attoparsec-0.14.4-K2NonRChA499lXmUebatlk base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    conduit-1.3.6-ITaJCDyfp5cDfMMsLf8jTY containers-0.6.5.1
    monad-logger-0.3.41-w1dtaqWu4N15RY8RRRglH mtl-2.2.2
    persistent-2.14.5.1-C5GFL9PbGXqIcXgZ85Sbo2
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    postgresql-simple-0.6.5-IpiNwTli1kvCc7RXUwU7Ov
    resource-pool-0.2.3.2-LQU0piIYTVWGxpRU2xNfiQ
    resourcet-1.2.6-E5mNqm21rnVD9a20HIq84b
    string-conversions-0.4.0.1-DIhGmAxRazx6IKbU2apUQz text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    vault-0.3.1.5-8OEJDELyKvr4pl4jcT5kn6

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-postgresql-2.13.4.1-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-postgresql
version:              2.13.4.1
visibility:           public
id:                   persistent-postgresql-2.13.4.1-3qHSHB0MwMR5RN2lY0n5c7
key:                  persistent-postgresql-2.13.4.1-3qHSHB0MwMR5RN2lY0n5c7
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  4d0ea9888645287437fcc292a3358755
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/persistent-postgresql-2.13.4.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.4.1-3qHSHB0MwMR5RN2lY0n5c7
depends:
    aeson-2.1.2.1-9T6l6SxZl5u1C3PaFHxalW
    attoparsec-0.14.4-IDdHCXuvqZFAtv2X99gOjm base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    conduit-1.3.6-7XhR2ax9qCFCYitRevMXBd containers-0.6.5.1
    monad-logger-0.3.41-JAIDrKrBCkQLDIOhdJTpWA mtl-2.2.2
    persistent-2.14.5.1-HcBdthREYvqBAXKzwtAKmr
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    postgresql-simple-0.6.5-16mM0NZ0t75BhnfZ1gcEvB
    resource-pool-0.2.3.2-JIDFIrIzVMx8IFKG0palm8
    resourcet-1.2.6-LfGMMseD8gYHfEEaghmlUT
    string-conversions-0.4.0.1-D6xKa1tiiemJrtOXoXDyxy text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    vault-0.3.1.5-HqV7RZWWbuN7yNYv2RT3ST

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
